Internal message/event queues. Queue management for agent loop.
Provides capacity-limited push, drain, and clear operations for the steering and follow-up message queues used by the agent loop.
Internal message/event queues. Queue management for agent loop.
Provides capacity-limited push, drain, and clear operations for the steering and follow-up message queues used by the agent loop.