Module stream_retry

Module stream_retry 

Shared streaming retry logic.

Constants

BACKOFF_BASE_SECS
Base delay in seconds for exponential backoff.
MAX_RETRIES
Maximum retry attempts for provider stream requests.

Traits

RetryCallback
Callback invoked each time a retry is about to happen.

Functions

stream_with_retry_core
Attempt to open a streaming connection to the provider with retry and exponential back-off.
stream_with_retry_core_with_breaker
Attempt to open a streaming connection to the provider with retry, exponential back-off, and an optional circuit breaker.