pub struct FileMutationQueue { /* private fields */ }Expand description
Serializes file mutation operations per canonical path.
Implementations
Sourceimpl FileMutationQueue
impl FileMutationQueue
Sourcepub async fn with_queue<F, Fut, T>(&self, path: &Path, f: F) -> T
pub async fn with_queue<F, Fut, T>(&self, path: &Path, f: F) -> T
Execute a mutation operation on a file, serialized per canonical path.
If the file doesn’t exist yet, uses the path as-is for the key. Periodically triggers cleanup of stale entries to prevent memory leaks.
Sourcepub async fn cleanup_stale(&self)
pub async fn cleanup_stale(&self)
Remove entries for files that no longer exist on disk.
This is called automatically every CLEANUP_INTERVAL operations, but
can also be called manually.
Sourcepub async fn entry_count(&self) -> usize
pub async fn entry_count(&self) -> usize
Returns the number of entries currently in the queue map.