pub fn apply_ops(
phases: &mut Vec<TodoPhase>,
ops: &[TodoOp],
) -> TodoUpdateResultExpand description
Apply a sequence of ops, returning the result + transitions + errors.
pub fn apply_ops(
phases: &mut Vec<TodoPhase>,
ops: &[TodoOp],
) -> TodoUpdateResultApply a sequence of ops, returning the result + transitions + errors.