Shared streaming retry logic.
Constants
- BACKOFF_
BASE_ SECS - Base delay in seconds for exponential backoff.
- MAX_
RETRIES - Maximum retry attempts for provider stream requests.
Traits
- Retry
Callback - Callback invoked each time a retry is about to happen.
Functions
- stream_
with_ retry_ core - Attempt to open a streaming connection to the provider with retry and exponential back-off.
- stream_
with_ retry_ core_ with_ breaker - Attempt to open a streaming connection to the provider with retry, exponential back-off, and an optional circuit breaker.